@@ -1,3 +1,7 @@
+"""
+boto3.__init__ stub.
+"""
+
 from typing import Any, Union
 
 from botocore.client import BaseClient
